==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/fi/help.php <==
<?php

return array(

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    "more_info_title" => "Lisätietoa",

    "audit_help" => "Tämän valitseminen muuttaa laitetiedot vastaamaan uutta sijaintia. Jos sitä ei ole valittu, sijainti kirjataan vain lokiin.<br><br> Huomaa, että jos laite on jo luovutettuna, tämä ei muuta sen henkilön, tai laitteen sijaintia mihin se on luovutettuna.",

    'assets' => 'Laitteet ovat nimmeitä joita seurataan sarjanumeron tai laitetunnisteen avulla. Laitteiksi määritellään yleensä arvokkaampaa omaisuutta, joiden tunnistaminen  yksilöllisesti on tärkeää.',

    'categories' => 'Kategoriat auttavat sinua järjestämään nimikkeitä. Kategorioita voivat olla esimerkiksi &quot;Työasemat&quot;, &quot;Kannettavat&quot;, &quot;Puhelimet&quot;, &quot;Tabletit&quot; ja niin edelleen, mutta voit käyttää kategorioita millä tahansa itsellesi sopivalla tavalla.',

    'accessories' => 'Oheistarvikkeet ovat laitteita joita annetaan käyttäjille, mutta joilla ei ole omia tunnisteita tai sarjanumeroita. Kuten vaikkapa hiiret ja näppäimistöt.',

    'companies'     => 'Yrityksiä voidaan käyttää yksinkertaisesti tunnisteena tai niitä voidaan käyttää rajoittamaan laitteiden näkyvyyttä käyttäjille, jne, jos täysi yritystuki on käytössä Admin asetuksissa.',

    'components'    => 'Komponentit ovat nimikkeitä, jotka ovat osa laitetta, esimerkiksi kiintolevyjä, RAM-muistia jne.',

    'consumables'   => 'Kulutustarvikkeet ovat kohteita jotka kuluvat ajan myötä. Esimerkiksi tulostimen muste tai kopiopaperi.',

    'depreciations' => 'Voit määrittää laitteille poistoja poistaaksesi omaisuuden arvoa suoraviivaisesti laskien.',



);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/fi/help.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'more_info_title' => 'Lisätietoa',

    'audit_help' => 'Tämän valitseminen muuttaa laitetiedot vastaamaan uutta sijaintia. Jos sitä ei ole valittu, sijainti kirjataan vain lokiin.<br><br> Huomaa, että jos laite on jo luovutettuna, tämä ei muuta sen henkilön, tai laitteen sijaintia mihin se on luovutettuna.',

    'assets' => 'Laitteet ovat nimmeitä joita seurataan sarjanumeron tai laitetunnisteen avulla. Laitteiksi määritellään yleensä arvokkaampaa omaisuutta, joiden tunnistaminen  yksilöllisesti on tärkeää.',

    'categories' => 'Kategoriat auttavat sinua järjestämään nimikkeitä. Kategorioita voivat olla esimerkiksi &quot;Työasemat&quot;, &quot;Kannettavat&quot;, &quot;Puhelimet&quot;, &quot;Tabletit&quot; ja niin edelleen, mutta voit käyttää kategorioita millä tahansa itsellesi sopivalla tavalla.',

    'accessories' => 'Oheistarvikkeet ovat laitteita joita annetaan käyttäjille, mutta joilla ei ole omia tunnisteita tai sarjanumeroita. Kuten vaikkapa hiiret ja näppäimistöt.',

    'companies'     => 'Yrityksiä voidaan käyttää yksinkertaisesti tunnisteena tai niitä voidaan käyttää rajoittamaan laitteiden näkyvyyttä käyttäjille, jne, jos täysi yritystuki on käytössä Admin asetuksissa.',

    'components'    => 'Komponentit ovat nimikkeitä, jotka ovat osa laitetta, esimerkiksi kiintolevyjä, RAM-muistia jne.',

    'consumables'   => 'Kulutustarvikkeet ovat kohteita jotka kuluvat ajan myötä. Esimerkiksi tulostimen muste tai kopiopaperi.',

    'depreciations' => 'Voit määrittää laitteille poistoja poistaaksesi omaisuuden arvoa suoraviivaisesti laskien.',

];
